@@ -16,9 +16,12 @@ use Video::Delay::Const;
 
 # Constants.
 Readonly::Scalar our $EMPTY_STR => q{};
+Readonly::Scalar our $MILISECONDS_IN_SECOND => 1000;
+Readonly::Scalar our $MINUTS_IN_HOUR => 60;
+Readonly::Scalar our $SECONDS_IN_MINUTE => 60;
 
 # Version.
-our $VERSION = 0.07;
+our $VERSION = 0.08;
 
 # Constructor.
 sub new {
@@ -111,9 +114,19 @@ sub _check_and_process_duration {
 		my $duration_suffix = $2;
 		if ($duration_suffix ne $EMPTY_STR) {
 			if ($duration_suffix eq 's') {
-				$self->{'duration'} = $duration_value * 1000;
+				$self->{'duration'} = $duration_value
+					* $MILISECONDS_IN_SECOND;
 			} elsif ($duration_suffix eq 'ms') {
 				$self->{'duration'} = $duration_value;
+			} elsif ($duration_suffix eq 'min') {
+				$self->{'duration'} = $duration_value
+					* $MILISECONDS_IN_SECOND
+					* $SECONDS_IN_MINUTE;
+			} elsif ($duration_suffix eq 'h') {
+				$self->{'duration'} = $duration_value
+					* $MILISECONDS_IN_SECOND
+					* $SECONDS_IN_MINUTE
+					* $MINUTS_IN_HOUR;
 			} else {
 				$err = 1;
 			}
@@ -124,7 +137,7 @@ sub _check_and_process_duration {
 
 	if ($err) {
 		err "Parameter 'duration' must be numeric value or numeric ".
-			"value with time suffix (s/ms).";
+			"value with time suffix.";
 	}
 	return;
 }
@@ -189,6 +202,8 @@ Video::Pattern - Video class for frame generation.
  Possible suffixes are:
  - ms for milisendons.
  - s for seconds.
+ - min for minute.
+ - h for hour.
  Default value is 10000 miliseconds.
 
 =item * C<fps>
@@ -219,7 +234,7 @@ Video::Pattern - Video class for frame generation.
 =head1 ERRORS
 
  new():
-         Parameter 'duration' must be numeric value or numeric value with time suffix (s/ms).
+         Parameter 'duration' must be numeric value or numeric value with time suffix.
          Parameter 'fps' must be numeric value.
          From Class::Utils::set_params():
                  Unknown parameter '%s'.
@@ -324,6 +339,6 @@ L<http://skim.cz>
 
 =head1 VERSION
 
-0.07
+0.08
 
 =cut
